Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(85)

Unified Diff: tests/html/request_animation_frame_test.dart

Issue 218273002: Upgrading tests with unittest deprecations (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/html/request_animation_frame_test.dart
diff --git a/tests/html/request_animation_frame_test.dart b/tests/html/request_animation_frame_test.dart
index 2bf8a0c493215b13320d424422a991daa0708bcd..f240b70ebcc199bde16bda99ee8f3f748a77c4b2 100644
--- a/tests/html/request_animation_frame_test.dart
+++ b/tests/html/request_animation_frame_test.dart
@@ -12,14 +12,14 @@ main() {
test('oneShot', () {
var frame = window.requestAnimationFrame(
- expectAsync1((timestamp) { }));
+ expectAsync((timestamp) { }));
});
test('twoShot', () {
var frame = window.requestAnimationFrame(
- expectAsync1((timestamp1) {
+ expectAsync((timestamp1) {
window.requestAnimationFrame(
- expectAsync1((timestamp2) {
+ expectAsync((timestamp2) {
// Not monotonic on Safari and IE.
// expect(timestamp2, greaterThan(timestamp1),
// reason: 'timestamps ordered');
@@ -29,7 +29,7 @@ main() {
// How do we test that a callback is never called? We can't wrap the uncalled
// callback with 'expectAsync1'. Will request several frames and try
// cancelling the one that is not the last.
test('cancel1', () {
var frame1 = window.requestAnimationFrame(
@@ -37,19 +37,19 @@ main() {
throw new Exception('Should have been cancelled');
});
var frame2 = window.requestAnimationFrame(
- expectAsync1((timestamp2) { }));
+ expectAsync((timestamp2) { }));
window.cancelAnimationFrame(frame1);
});
test('cancel2', () {
var frame1 = window.requestAnimationFrame(
- expectAsync1((timestamp1) { }));
+ expectAsync((timestamp1) { }));
var frame2 = window.requestAnimationFrame(
(timestamp2) {
throw new Exception('Should have been cancelled');
});
var frame3 = window.requestAnimationFrame(
- expectAsync1((timestamp3) { }));
+ expectAsync((timestamp3) { }));
window.cancelAnimationFrame(frame2);
});
}
@@ -29,7 +29,7 @@ main() {
// How do we test that a callback is never called? We can't wrap the uncalled
- // callback with 'expectAsync1'. Will request several frames and try
+ // callback with 'expectAsync'. Will request several frames and try
// cancelling the one that is not the last.
test('cancel1', () {

Powered by Google App Engine
This is Rietveld 408576698